Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type DockerParser ¶
type DockerParser struct{}
DockerParser detects a Docker Compose file and extracts service names.
func (*DockerParser) Name ¶
func (d *DockerParser) Name() string
type GoParser ¶
type GoParser struct{}
GoParser detects go.mod in the repo root and extracts Go project info.
type JustParser ¶
type JustParser struct{}
JustParser detects a Justfile in the repo root and extracts recipes.
func (*JustParser) Name ¶
func (j *JustParser) Name() string
type MakeParser ¶
type MakeParser struct{}
MakeParser detects a Makefile in the repo root and extracts targets.
func (*MakeParser) Name ¶
func (m *MakeParser) Name() string
type NodeParser ¶
type NodeParser struct{}
NodeParser detects package.json and extracts Node.js project info.
func (*NodeParser) Name ¶
func (n *NodeParser) Name() string
type Parser ¶
Parser detects project tooling and extracts relevant info. Returns nil result if this parser doesn't apply.
type PythonParser ¶
type PythonParser struct{}
PythonParser detects Python project indicators and extracts project info.
func (*PythonParser) Name ¶
func (p *PythonParser) Name() string
type ScriptsParser ¶
type ScriptsParser struct{}
ScriptsParser looks for bin/ and scripts/ directories and lists script files.
func (*ScriptsParser) Name ¶
func (s *ScriptsParser) Name() string
Click to show internal directories.
Click to hide internal directories.